// Scratch JS extension for Ryze Tello
// This requires Tello.js (node.js HTTP server app.)

(function(ext) {
    baseURL = "http://localhost:8001";

    // Cleanup function when the extension is unloaded
    ext._shutdown = function() {};

    // Status reporting code
    ext._getStatus = function() {
        return {status: 2, msg: 'Ready'};
    };


    //Takeoff command
    ext.takeoff_block = function() {
	cmdURL = baseURL + "/takeoff";
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Land command
    ext.land_block = function() {
	cmdURL = baseURL + "/land";
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly up command
    ext.up_block = function(dist) {
	cmdURL = baseURL + "/up/" + dist;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly down command
    ext.down_block = function(dist) {
	cmdURL = baseURL + "/down/" + dist;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly left command
    ext.left_block = function(dist) {
	cmdURL = baseURL + "/left/" + dist;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly right command
    ext.right_block = function(dist) {
	cmdURL = baseURL + "/right/" + dist;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly forward command
    ext.forward_block = function(dist) {
	cmdURL = baseURL + "/forward/" + dist;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly back command
    ext.back_block = function(dist) {
	cmdURL = baseURL + "/back/" + dist;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly CW command
    ext.cw_block = function(and) {
	cmdURL = baseURL + "/cw/" + and;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Fly CCW command
    ext.ccw_block = function(ang) {
	cmdURL = baseURL + "/ccw/" + ang;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Flip command
    ext.flip_block = function(mode) {
	cmdURL = baseURL + "/flip/" +  mode;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Set speed command
    ext.setspeed_block = function(speed) {
	cmdURL = baseURL + "/setspeed/" + speed;
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Stream ON command
    ext.setstreamon_block = function() {
	cmdURL = baseURL + "/streamon";
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };

    //Stream OFF command
    ext.land_block = function() {
	cmdURL = baseURL + "/streamoff";
        $.ajax({
	  type: "GET",
          url: cmdURL,
	});
    };


    // Block and block menu descriptions
    var descriptor = {
        blocks: [
            // Block type, block name, function name
            [' ', '離陸', 'takeoff_block'],
            [' ', '着陸', 'land_block'],
            [' ', '%n cm上昇', 'up_block', 20],
            [' ', '%n cm下降', 'down_block', 20],
            [' ', '左へ %n cm移動', 'left_block', 20],
            [' ', '右へ %n cm移動', 'right_block', 20],
            [' ', '前へ %n cm移動', 'forward_block', 20],
            [' ', '後へ %n cm移動', 'back_block', 20],
            [' ', '時計まわりに %n 度回転', 'cw_block', 90],
            [' ', '反時計まわりに %n 度回転', 'ccw_block', 90],
            [' ', ' %s でフリップ', 'flip_block', 'f'],
            [' ', '速度を %n に設定', 'setspeed_block', 80],
            [' ', '動画開始', 'setstreamon_block', 80],
            [' ', '動画終了', 'setstreamoff_block', 'f'],
        ]
    };

    // Register the extension
    ScratchExtensions.register('Tello Control', descriptor, ext);
})({});
